==> lvm_0.6.tar.gz: LVM/0.6/tools/lib/lv_create_node.c <==
/*
 * tools/lib/lv_create_node.c
 *
 * Copyright (C) 1997 - 1999  Heinz Mauelshagen, Germany
 *
 * May 1997
 *
 *
 * This LVM library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This LVM library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this LVM library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 *
 */

/*
 * Changelog
 *
 *    11/01/1998 - added unlink() on logical volume special file
 *    29/04/1998 - added vg_number, lv_number usage to get
 *                 seperation from LV name
 *               - changed to new lv_create_kdev_t()
 *    27/07/1998 - enhanced error check
 *
 */

#include <liblvm.h>

int lv_create_node ( lv_t *lv) {
   int ret = 0;

#ifdef DEBUG
   debug ( "lv_create_node -- CALLED\n");
#endif

   if ( lv == NULL || lv_check_consistency ( lv) < 0) {
      ret = -LVM_EPARAM;
      goto lv_create_node_end;
   }

   if ( unlink ( lv->lv_name) == -1) {
      if ( errno != ENOENT) {
         ret = -LVM_ELV_CREATE_NODE_UNLINK;
         goto lv_create_node_end;
      }
   }

   if ( mknod ( lv->lv_name, S_IFBLK | S_IRUSR | S_IWUSR | S_IRGRP,
                lv->lv_dev) == -1)
      ret = -LVM_ELV_CREATE_MODE_MKNOD;
   else if ( chmod ( lv->lv_name, 0640) == -1) ret = -LVM_ELV_CREATE_MODE_CHMOD;

lv_create_node_end:
#ifdef DEBUG
   debug ( "lv_create_node -- LEAVING with %d\n", ret);
#endif
   return ret;
}

==> lvm_0.8.1.tar.gz: LVM/0.8.1/tools/lib/lv_create_node.c <==
/*
 * tools/lib/lv_create_node.c
 *
 * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
 *
 * May 1997
 * January 2000
 *
 *
 * This LVM library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This LVM library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this LVM library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 *
 */

/*
 * Changelog
 *
 *    11/01/1998 - added unlink() on logical volume special file
 *    29/04/1998 - added vg_number, lv_number usage to get
 *                 seperation from LV name
 *               - changed to new lv_create_kdev_t()
 *    27/07/1998 - enhanced error check
 *    31/01/2000 - use debug_enter()/debug_leave()
 *
 */

#include <liblvm.h>
#include <grp.h>
#include <sys/types.h>

int lv_create_node ( lv_t *lv) {
   int ret = 0;
   struct group *group;

#ifdef DEBUG
   debug_enter ( "lv_create_node -- CALLED\n");
#endif

   if ( lv == NULL || lv_check_consistency ( lv) < 0) {
      ret = -LVM_EPARAM;
      goto lv_create_node_end;
   }

   if ( unlink ( lv->lv_name) == -1) {
      if ( errno != ENOENT) {
         ret = -LVM_ELV_CREATE_NODE_UNLINK;
         goto lv_create_node_end;
      }
   }

   if (mknod(lv->lv_name, S_IFBLK | S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP,
            lv->lv_dev) == -1)
      ret = -LVM_ELV_CREATE_MODE_MKNOD;
   else if (!(group = getgrnam("disk")) ||
           chown(lv->lv_name, -1, group->gr_gid) == -1)
      ret = -LVM_ELV_CREATE_MODE_CHMOD;

lv_create_node_end:
#ifdef DEBUG
   debug_leave ( "lv_create_node -- LEAVING with %d\n", ret);
#endif
   return ret;
}
